<?xml version="1.0" encoding="UTF-8"?>
<!--
 =================================================================
  Licensed Materials - Property of IBM

  WebSphere Commerce

  (C) Copyright IBM Corp. 2009 All Rights Reserved.

  US Government Users Restricted Rights - Use, duplication or
  disclosure restricted by GSA ADP Schedule Contract with
  IBM Corp.
 =================================================================
-->
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<!-- handles purchase condition -->
	<xsl:template name="PurchaseConditionTemplate" match="/">
		<PurchaseCondition impl="com.ibm.commerce.marketing.promotion.condition.PurchaseCondition">
			<Pattern impl="com.ibm.commerce.marketing.promotion.condition.Pattern">
				<Constraint impl="com.ibm.commerce.marketing.promotion.condition.Constraint">
					<WeightedRange impl="com.ibm.commerce.marketing.promotion.condition.WeightedRange">
						<LowerBound>1</LowerBound>
						<UpperBound>-1</UpperBound>
						<Weight>1</Weight>
					</WeightedRange>
					<FilterChain impl="com.ibm.commerce.marketing.promotion.condition.FilterChain">
						<Filter impl="com.ibm.commerce.marketing.promotion.condition.MultiSKUFilter">
							<xsl:for-each select="PromotionData/Elements/PurchaseCondition/IncludeCatalogEntryIdentifier">
								<IncludeCatEntryKey>
									<xsl:call-template name="CatalogEntryKeyTemplate">
										<xsl:with-param name="dn" select="Data/DN" />
										<xsl:with-param name="sku" select="Data/SKU" />
									</xsl:call-template>
								</IncludeCatEntryKey>
							</xsl:for-each>
							<xsl:for-each select="PromotionData/Elements/PurchaseCondition/ExcludeCatalogEntryIdentifier">
								<ExcludeCatEntryKey>
									<xsl:call-template name="CatalogEntryKeyTemplate">
										<xsl:with-param name="dn" select="Data/DN" />
										<xsl:with-param name="sku" select="Data/SKU" />
									</xsl:call-template>
								</ExcludeCatEntryKey>
							</xsl:for-each>
						</Filter>
					</FilterChain>
				</Constraint>
			</Pattern>
			<Distribution impl="com.ibm.commerce.marketing.promotion.reward.Distribution">
				<Type>Volume</Type>
				<Base>Cost</Base>
				<Currency>USD</Currency>
				<Range impl="com.ibm.commerce.marketing.promotion.reward.DistributionRange">
					<UpperBound>-1</UpperBound>
					<LowerBound><xsl:value-of select="PromotionData/Elements/PurchaseCondition/Data/BaseItemTotalPrice" /></LowerBound>
					<UpperBoundIncluded>true</UpperBoundIncluded>
					<LowerBoundIncluded>true</LowerBoundIncluded>
					<RewardChoice>
						<Reward impl="com.ibm.commerce.marketing.promotion.reward.DefaultReward">
							<xsl:for-each select="PromotionData/Elements/PurchaseCondition/GiftCatalogEntryIdentifier">
								<AdjustmentFunction impl="com.ibm.commerce.marketing.promotion.reward.AdjustmentFunction">
									<FilterChain impl="com.ibm.commerce.marketing.promotion.condition.FilterChain">
										<Filter impl="com.ibm.commerce.marketing.promotion.condition.DummyFilter" />
									</FilterChain>
									<Adjustment impl="com.ibm.commerce.marketing.promotion.reward.FreePurchasableGiftAdjustment">
										<GiftItem>
											<xsl:call-template name="CatalogEntryKeyTemplate">
												<xsl:with-param name="dn" select="Data/DN" />
												<xsl:with-param name="sku" select="Data/SKU" />
											</xsl:call-template>
										</GiftItem>
										<Quantity><xsl:value-of select="Data/giftQuantity" /></Quantity>
										<AddStrategy>1</AddStrategy>
										<AdjustmentType>wholeOrder</AdjustmentType>
									</Adjustment>
								</AdjustmentFunction>
							</xsl:for-each>
						</Reward>
					</RewardChoice>
				</Range>
				<PatternFilter impl="com.ibm.commerce.marketing.promotion.condition.DummyPatternFilter" />
			</Distribution>
		</PurchaseCondition>
	</xsl:template>
	<!-- handles CatalogEntryKey -->
	<xsl:template name="CatalogEntryKeyTemplate">
		<xsl:param name="dn" />
		<xsl:param name="sku" />
		<CatalogEntryKey>
			<DN><xsl:value-of select="$dn" /></DN>
			<SKU><xsl:value-of select="$sku" /></SKU>
		</CatalogEntryKey>
	</xsl:template>
</xsl:transform>